# insults

A Python package for helping you call your users dirty names.

# Installation

Install using ```pip install pyinsults```


# Usage

```from pyinsults import insults ```
> Done in [.01s]

``` print(insults.short_insult()) ```
> dickwad

``` print(insults.long_insult()) ```
> stinking dickwad


# Deployment

Build using ```python setup.py sdist bdist_wheel```

Upload using ```twine upload dist/*```
